@@ -7,10 +7,11 @@
 
   \author Satofumi KAMIMURA
 
-  $Id: BatmonWidget.h 13 2009-12-29 03:17:42Z satofumi $
+  $Id: BatmonWidget.h 26 2010-01-02 01:37:37Z satofumi $
 */
 
 #include <QWidget>
+#include <QSystemTrayIcon>
 #include <memory>
 
 
@@ -21,7 +22,7 @@ class BatmonWidget : public QWidget
 
 public:
   //! コンストラクタ
-  BatmonWidget(QWidget* widget = NULL);
+  explicit BatmonWidget(bool geometry_specified, QWidget* widget = NULL);
   ~BatmonWidget(void);
 
 private slots:
